@@ -39,6 +39,7 @@
 GST_DEBUG_CATEGORY (play_debug);
 #define GST_CAT_DEFAULT play_debug
 
+extern GstPlay *player;
 static gboolean play_next (GstPlay * play);
 static gboolean play_prev (GstPlay * play);
 static void play_reset (GstPlay * play);
@@ -425,6 +426,15 @@ play_set_relative_volume (GstPlay * play, gdouble volume_step)
   g_print ("Volume: %.0f%%                  \n", volume * 100);
 }
 
+static gdouble
+get_volume (GtkWidget *widget, GstPlay *play)
+{
+	gdouble volume;
+	g_object_get (player, "volume", &volume, NULL);
+	return volume;
+}
+
+
 static gchar *
 play_uri_get_display_name (GstPlayer * player, const gchar * uri)
 {
@@ -648,13 +658,13 @@ keyboard_cb (const gchar * key_input, gpointer user_data)
 void
 gnome_internet_radio_locator_player_new (GstPlayer * player, const gchar * next_uri)
 {
-  gst_player_set_uri(player, next_uri);
+	gst_player_set_uri(player, next_uri);
 }
 
 void
 gnome_internet_radio_locator_player_stop (GstPlayer *player)
 {
-  gst_player_stop(player);
+	gst_player_stop(player);
 }
 
 void
@@ -662,7 +672,7 @@ gnome_internet_radio_locator_player_pause (GstPlayer *player)
 {
   /* FIXME: Unable to quit after pause is called for the first time. */
 #if 0
-  gst_player_pause(player);
+	gst_player_pause(player);
 #endif
 }
 
